@@ -1,13 +1,6 @@
 from __future__ import annotations
 
-from typing import (
-    Any,
-    Dict,
-    List,
-    Union,
-    TypeVar,
-    TYPE_CHECKING
-)
+from typing import Any, Dict, List, Union, TypeVar, TYPE_CHECKING
 
 import pydantic
 from httpx import Response
